==> chaotic_helper-1.5.0.tar.gz: lib/init.dart <==
library init;

import 'dart:io';

import 'package:intl/intl.dart';
import 'package:process_run/shell.dart';

part 'init/extensions.dart';

part 'init/files_and_folders.dart';

part 'init/files_templates.dart';

part 'init/init_helper.dart';

/// this function just return enum as a string
///
/// ```dart
/// enum Status{
///    Active
/// }
///  _enumToString(Status.Active); will return `Active`
/// ```
String _enumToString<T>(T value) => value.toString().split('.').last;

class Chaotic {
  /// when it true it will 'add, commit and push' automatically to github server
  ///
  /// default value is false
  static bool useGit = false;

  /// it will add package to `pubspec.yaml` with latest version
  ///
  /// and run pub get command.
  /// ```dart
  /// addPackage(Packages.dio)
  /// ```
  static Future<void> addPackage(Packages package) async {
    await Shell().run('flutter pub add ${_enumToString(package)}');
    await Shell().run('flutter pub get');
    await git(_enumToString('add $package package'));
  }

  static Future<void> addPackages(List<Packages> packages) async {
    for (final package in packages) {
      await Shell().run('flutter pub add ${_enumToString(package)}');
    }
    await Shell().run('flutter pub get');
    await git(_enumToString('add $packages packages'));
  }

  /// make sure you deleted all files from lib folder before run this function.
  ///
  /// it will =>
  /// 1. create project structure.
  /// 2. add some required packages.
  /// 3. add assets to projects.
  /// 4. remove comments from pubspec.yaml .
  /// 5. run pub get command
  static Future<void> init() async {
    await _createProjectStructure();
    await _addPackages();
    await _initYaml();
  }

  /// this function will =>
  /// 1. create folder in screen folder
  /// 2. create file for screen class in this new folder
  /// 3. create file for provider class in this new folder
  /// 4. export this two files into screens.dart file
  static Future<void> newScreen(String screenName) async {
    final newScreenFolder = _getDir(screenName, _screenFolder);
    final newScreenFile = _getFile('$screenName.dart', newScreenFolder);
    final newProviderFile =
        _getFile('${screenName}_provider.dart', newScreenFolder);
    if (newScreenFile.existsSync()) {
      print('$screenName is exists before');
      return;
    }
    newScreenFile.createSync(recursive: true);
    await _exportNewScreen(screenName);
    await newScreenFile.writeAsString(_newScreenTemp(screenName.toCamelcase()));
    await newProviderFile
        .writeAsString(_newProviderTemp(screenName.toCamelcase()));
    await git('add new screen $screenName');
  }

  /// this function will =>
  /// 1. create file in common folder
  /// 2. export this file into commons.dart file
  static Future<void> newCommon(String commonName) async {
    final newCommonFile = _getFile('$commonName.dart', _commonFolder);
    if (newCommonFile.existsSync()) {
      print('$commonName is exists before');
      return;
    }
    newCommonFile.createSync(recursive: true);
    await _exportNewCommon(commonName);
    await git('new common $commonName');
  }

  /// this function will =>
  /// 1. create file widget class in widget folder
  /// 2. export this file into widgets.dart file
  static Future<void> newWidget(String widgetName) async {
    final newWidgetFile = _getFile('$widgetName.dart', _widgetFolder);
    if (newWidgetFile.existsSync()) {
      print('$widgetName is exists before');
      return;
    }
    newWidgetFile.createSync(recursive: true);
    await newWidgetFile.writeAsString(_newWidgetTemp(widgetName.toCamelcase()));
    await _exportNewWidget(widgetName);
    await git('new widget $widgetName');
  }

  /// this function will =>
  /// 1. create file model class in model folder
  /// 2. export this file into model.dart file
  static Future<void> newModel(String modelName) async {
    final newModelFile = _getFile('$modelName.dart', _modelFolder);
    if (newModelFile.existsSync()) {
      print('$modelName is exists before');
      return;
    }
    newModelFile.createSync(recursive: true);
    newModelFile.writeAsString(_modelTemp(modelName));
    await _exportNewModel(modelName);
    await git('new model $modelName');
  }

  /// this function will =>
  /// 1. create folder in assets/image
  /// 2. add this asset in pubspec.yaml and run pub get command
  static Future<void> newAsset(String newAsset) async {
    final newImageFolder = _getDir(newAsset, _imagesFolder);
    if (newImageFolder.existsSync()) {
      print('$newAsset is exists before');
      return;
    }
    newImageFolder.createSync(recursive: true);
    final yamlContent = await _yamlFile.readAsString();
    final newYamlContent = yamlContent.replaceAll('''assets:''', '''
assets:
    - assets/images/$newAsset/''');
    await _yamlFile.writeAsString(newYamlContent);
    await Shell().run('''flutter pub get''');
    await git('new asset $newAsset');
  }

  /// this function will =>
  /// 1. create file for this service in service folder
  /// 2. export this file into services.dart file
  static Future<void> newService(String serviceName) async {
    final newServiceFile = _getFile('$serviceName.dart', _serviceFolder);
    if (newServiceFile.existsSync()) {
      print('$serviceName is exists before');
      return;
    }
    newServiceFile.createSync(recursive: true);
    await newServiceFile
        .writeAsString(_newServiceTemp(serviceName.toCamelcase()));
    await _exportNewService(serviceName);
    await git('new service $serviceName');
  }

  /// this function will =>
  /// 1. create folder local_model in screen/[screenName] folder
  /// 2. create file in this folder
  /// 3. export this file into local_models.dart file
  static Future<void> newLocalModel(
    String localModelName,
    String screenName,
  ) async {
    final screenFolder = _getDir(screenName, _screenFolder);
    final localModelFolder = _getDir('local_model', screenFolder);
    final localModelsFile = _getFile('local_models.dart', localModelFolder);
    if (!screenFolder.existsSync()) await newScreen(screenName);
    if (!localModelFolder.existsSync()) await localModelFolder.create();
    final newModelFile = _getFile(
      '$localModelName.dart',
      localModelFolder,
    );
    if (newModelFile.existsSync()) {
      print('$localModelName is exists before');
      return;
    }
    await localModelsFile.writeAsString(
      '''\nexport '$localModelName.dart';''',
      mode: FileMode.append,
    );
    await newModelFile.writeAsString(_modelTemp(localModelName));
    await git('new local model $localModelName in $screenName screen');
  }

  /// this function will =>
  /// 1. create folder local_widget in screen/[screenName] folder
  /// 2. create file in this folder
  /// 3. export this file into local_widgets.dart file
  static Future<void> newLocalWidget(
      String localWidgetName, String screenName) async {
    final screenFolder = _getDir(screenName, _screenFolder);
    final localWidgetFolder = _getDir('local_widget', screenFolder);
    if (!screenFolder.existsSync()) await newScreen(screenName);
    if (!localWidgetFolder.existsSync()) await localWidgetFolder.create();
    final localWidgetsFile = _getFile(
      'local_widgets.dart',
      localWidgetFolder,
    );
    final newWidgetFile = _getFile(
      '$localWidgetName.dart',
      localWidgetFolder,
    );
    if (newWidgetFile.existsSync()) {
      print('$localWidgetName is exists before');
      return;
    }
    await localWidgetsFile.writeAsString(
      '''\nexport '$localWidgetName.dart';''',
      mode: FileMode.append,
    );
    await newWidgetFile
        .writeAsString(_newWidgetTemp(localWidgetName.toCamelcase()));
    await git('new local widget $localWidgetName in $screenName screen');
  }

  /// this function will =>
  /// 1. git add .
  /// 2. git commit -m [actionName]
  /// 3. git push
  /// 4. git status
  static Future<void> git(String actionName) async {
    if (!useGit) return;
    await Shell().run('''git add .''');
    await Shell().run('''git commit -m  "$actionName"''');
    await Shell().run('''git push''');
    await Shell().run('''git status''');
  }

  /// it will run [Chaotic.git(DateTime.now())]
  static Future<void> endOfDay() async {
    await git(DateFormat.yMd().format(DateTime.now()));
  }

  /// call it at end of main function in bin/main.dart
  static Future<void> clear() async {
    File('./bin/main.dart').writeAsStringSync(_clearTemp(Chaotic.useGit));
  }
}

enum Packages {
// UI
  flutter_svg,
  dotted_border,
  pinput,
  toggle_switch,
  sizer,
  bot_toast,
  flutter_spinkit,
  cached_network_image,
  font_awesome_flutter,
  flutter_staggered_grid_view,
// Device
  platform_device_id,
  package_info_plus,
  permission_handler,
// State Management
  get,
  provider,
// API requests and Connectivity
  dio,
  path_provider,
// Storage
  shared_preferences,
  mysql1,
// Date
  hijri_picker,
  intl,
// Firebase And notification
  firebase_messaging,
  flutter_local_notifications,
  cloud_firestore,
  firebase_storage,
// Google
  google_maps_flutter,
  location,
// Launcher and Pickers
  image_picker,
  url_launcher,
// Translation
  easy_localization,
// Other
  introduction_screen,
  connectivity,
}

==> chaotic_helper-1.7.0.tar.gz: lib/init.dart <==
library init;

import 'dart:io';

import 'package:intl/intl.dart';
import 'package:process_run/shell.dart';

part 'init/extensions.dart';

part 'init/files_and_folders.dart';

part 'init/files_templates.dart';

part 'init/init_helper.dart';

/// this function just return enum as a string
///
/// ```dart
/// enum Status{
///    Active
/// }
///  _enumToString(Status.Active); will return `Active`
/// ```
String _enumToString<T>(T value) => value.toString().split('.').last;

class Chaotic {
  /// when it true it will 'add, commit and push' automatically to github server
  ///
  /// default value is false
  static bool useGit = false;
  static String? applicationFile;

  /// it will add package to `pubspec.yaml` with latest version
  ///
  /// and run pub get command.
  /// ```dart
  /// addPackage(Packages.dio)
  /// ```
  static Future<void> addPackage(Packages package) async {
    await Shell().run('flutter pub add ${_enumToString(package)}');
    await Shell().run('flutter pub get');
    await git(_enumToString('add $package package'), true);
  }

  static Future<void> addPackages(List<Packages> packages) async {
    for (final package in packages) {
      await Shell().run('flutter pub add ${_enumToString(package)}');
    }
    await Shell().run('flutter pub get');
    await git(_enumToString('add $packages packages'), true);
  }

  /// make sure you deleted all files from lib folder before run this function.
  ///
  /// it will =>
  /// 1. create project structure.
  /// 2. add some required packages.
  /// 3. add assets to projects.
  /// 4. remove comments from pubspec.yaml .
  /// 5. run pub get command
  static Future<void> init() async {
    await _createProjectStructure();
    await _addPackages();
    await _initYaml();
  }

  /// this function will =>
  /// 1. create folder in screen folder
  /// 2. create file for screen class in this new folder
  /// 3. create file for provider class in this new folder
  /// 4. export this two files into screens.dart file
  static Future<void> newScreen(String screenName) async {
    final newScreenFolder = _getDir(screenName, _screenFolder);
    final newScreenFile = _getFile('$screenName.dart', newScreenFolder);
    final newProviderFile =
        _getFile('${screenName}_provider.dart', newScreenFolder);
    if (newScreenFile.existsSync()) {
      print('$screenName is exists before');
      return;
    }
    newScreenFile.createSync(recursive: true);
    await _exportNewScreen(screenName);
    await newScreenFile.writeAsString(_newScreenTemp(screenName.toCamelcase()));
    await newProviderFile
        .writeAsString(_newProviderTemp(screenName.toCamelcase()));
    await git('add new screen $screenName', true);
  }

  /// this function will =>
  /// 1. create file in common folder
  /// 2. export this file into commons.dart file
  static Future<void> newCommon(String commonName) async {
    final newCommonFile = _getFile('$commonName.dart', _commonFolder);
    if (newCommonFile.existsSync()) {
      print('$commonName is exists before');
      return;
    }
    newCommonFile.createSync(recursive: true);
    await _exportNewCommon(commonName);
    await git('new common $commonName', true);
  }

  /// this function will =>
  /// 1. create file widget class in widget folder
  /// 2. export this file into widgets.dart file
  static Future<void> newWidget(String widgetName) async {
    final newWidgetFile = _getFile('$widgetName.dart', _widgetFolder);
    if (newWidgetFile.existsSync()) {
      print('$widgetName is exists before');
      return;
    }
    newWidgetFile.createSync(recursive: true);
    await newWidgetFile.writeAsString(_newWidgetTemp(widgetName.toCamelcase()));
    await _exportNewWidget(widgetName);
    await git('new widget $widgetName', true);
  }

  /// this function will =>
  /// 1. create file model class in model folder
  /// 2. export this file into model.dart file
  static Future<void> newModel(String modelName) async {
    final newModelFile = _getFile('$modelName.dart', _modelFolder);
    if (newModelFile.existsSync()) {
      print('$modelName is exists before');
      return;
    }
    newModelFile.createSync(recursive: true);
    newModelFile.writeAsString(_modelTemp(modelName));
    await _exportNewModel(modelName);
    await git('new model $modelName', true);
  }

  /// this function will =>
  /// 1. create folder in assets/image
  /// 2. add this asset in pubspec.yaml and run pub get command
  static Future<void> newAsset(String newAsset) async {
    final newImageFolder = _getDir(newAsset, _imagesFolder);
    if (newImageFolder.existsSync()) {
      print('$newAsset is exists before');
      return;
    }
    newImageFolder.createSync(recursive: true);
    final yamlContent = await _yamlFile.readAsString();
    final newYamlContent = yamlContent.replaceAll('''assets:''', '''
assets:
    - assets/images/$newAsset/''');
    await _yamlFile.writeAsString(newYamlContent);
    await Shell().run('''flutter pub get''');
    await git('new asset $newAsset', true);
  }

  /// this function will =>
  /// 1. create file for this service in service folder
  /// 2. export this file into services.dart file
  static Future<void> newService(String serviceName) async {
    final newServiceFile = _getFile('$serviceName.dart', _serviceFolder);
    if (newServiceFile.existsSync()) {
      print('$serviceName is exists before');
      return;
    }
    newServiceFile.createSync(recursive: true);
    await newServiceFile
        .writeAsString(_newServiceTemp(serviceName.toCamelcase()));
    await _exportNewService(serviceName);
    await git('new service $serviceName', true);
  }

  /// this function will =>
  /// 1. create folder local_model in screen/[screenName] folder
  /// 2. create file in this folder
  /// 3. export this file into local_models.dart file
  static Future<void> newLocalModel(
    String localModelName,
    String screenName,
  ) async {
    final screenFolder = _getDir(screenName, _screenFolder);
    final localModelFolder = _getDir('local_model', screenFolder);
    final localModelsFile = _getFile('local_models.dart', localModelFolder);
    if (!screenFolder.existsSync()) await newScreen(screenName);
    if (!localModelFolder.existsSync()) await localModelFolder.create();
    final newModelFile = _getFile(
      '$localModelName.dart',
      localModelFolder,
    );
    if (newModelFile.existsSync()) {
      print('$localModelName is exists before');
      return;
    }
    await localModelsFile.writeAsString(
      '''\nexport '$localModelName.dart';''',
      mode: FileMode.append,
    );
    await newModelFile.writeAsString(_modelTemp(localModelName));
    await git('new local model $localModelName in $screenName screen', true);
  }

  /// this function will =>
  /// 1. create folder local_widget in screen/[screenName] folder
  /// 2. create file in this folder
  /// 3. export this file into local_widgets.dart file
  static Future<void> newLocalWidget(
      String localWidgetName, String screenName) async {
    final screenFolder = _getDir(screenName, _screenFolder);
    final localWidgetFolder = _getDir('local_widget', screenFolder);
    if (!screenFolder.existsSync()) await newScreen(screenName);
    if (!localWidgetFolder.existsSync()) await localWidgetFolder.create();
    final localWidgetsFile = _getFile(
      'local_widgets.dart',
      localWidgetFolder,
    );
    final newWidgetFile = _getFile(
      '$localWidgetName.dart',
      localWidgetFolder,
    );
    if (newWidgetFile.existsSync()) {
      print('$localWidgetName is exists before');
      return;
    }
    await localWidgetsFile.writeAsString(
      '''\nexport '$localWidgetName.dart';''',
      mode: FileMode.append,
    );
    await newWidgetFile
        .writeAsString(_newWidgetTemp(localWidgetName.toCamelcase()));
    await git('new local widget $localWidgetName in $screenName screen', true);
  }

  /// this function will =>
  /// 1. git add .
  /// 2. git commit -m [actionName]
  /// 3. git push
  /// 4. git status
  static Future<void> git(String actionName, [bool check = false]) async {
    if (check && !useGit) return;
    await Shell().run('''git add .''');
    await Shell().run('''git commit -m  "$actionName"''');
    await Shell().run('''git push''');
    await Shell().run('''git status''');
  }

  /// it will run [Chaotic.git(DateTime.now())]
  static Future<void> endOfDay() async {
    await git(DateFormat.yMd().format(DateTime.now()));
  }

  /// call it at end of main function in bin/main.dart
  static Future<void> clear() async {
    File('./bin/main.dart').writeAsStringSync(_clearTemp(Chaotic.useGit));
  }
}

enum Packages {
// UI
  flutter_svg,
  dotted_border,
  pinput,
  toggle_switch,
  sizer,
  bot_toast,
  flutter_spinkit,
  cached_network_image,
  font_awesome_flutter,
  flutter_staggered_grid_view,
  story_view,
  flutter_slidable,
  carousel_slider,
// Device
  platform_device_id,
  package_info_plus,
  permission_handler,
// State Management
  get,
  provider,
// API requests and Connectivity
  dio,
  path_provider,
// Storage
  shared_preferences,
  mysql1,
// Date
  hijri_picker,
  intl,
// Firebase And notification
  firebase_messaging,
  flutter_local_notifications,
  cloud_firestore,
  firebase_storage,
  firebase_core,
// Google
  google_maps_flutter,
  location,
  geocoding,
  google_place,
// Launcher and Pickers
  image_picker,
  url_launcher,
// Translation
  easy_localization,
  easy_logger,
// Other
  introduction_screen,
  connectivity,
  faker_dart,
}
